<?php
/*-----------------------------------------------------------------------------------*/
/*	Do not remove these lines, sky will fall on your head.
/*-----------------------------------------------------------------------------------*/
define( 'MTS_THEME_NAME', 'school' );
define( 'MTS_THEME_TEXTDOMAIN', 'school');
define( 'MTS_THEME_VERSION', '1.1.13' );
require_once( dirname( __FILE__ ) . '/theme-options.php' );
if ( ! isset( $content_width ) ) $content_width = 1060;

/*-----------------------------------------------------------------------------------*/
/*	Load Options
/*-----------------------------------------------------------------------------------*/
$mts_options = get_option( MTS_THEME_NAME );

/*-----------------------------------------------------------------------------------*/
/*	Load Translation Text Domain
/*-----------------------------------------------------------------------------------*/
load_theme_textdomain( 'mythemeshop', get_template_directory().'/lang' );

// Custom translations
if ( !empty( $mts_options['translate'] )) {
    $mts_translations = get_option( 'mts_translations_'.MTS_THEME_NAME );//$mts_options['translations'];
    function mts_custom_translate( $translated_text, $text, $domain ) {
        if ( $domain == 'mythemeshop' || $domain == 'nhp-opts' ) {
            global $mts_translations;
            if ( !empty( $mts_translations[$text] )) {
                $translated_text = $mts_translations[$text];
            }
        }
    	return $translated_text;
        
    }
    add_filter( 'gettext', 'mts_custom_translate', 20, 3 );
}

if ( function_exists( 'add_theme_support' ) ) add_theme_support( 'automatic-feed-links' );

/*-----------------------------------------------------------------------------------*/
/*  Disable theme updates from WordPress.org theme repository
/*-----------------------------------------------------------------------------------*/
// Check if MTS Connect plugin already done this
if ( !class_exists('mts_connection') ) {
    // If wrong updates are already shown, delete transient so that we can run our workaround
    if ( false === get_option( 'mts_wp_org_updates_disabled' ) ) { // check only once
        update_option( 'mts_wp_org_updates_disabled', 'disabled' );

        delete_site_transient('update_themes' );
        delete_site_transient('update_plugins' );
    }
    // Hide mts themes/plugins
    add_action('admin_init', 'mts_remove_themes_plugins_from_update', 20 );
    function mts_remove_themes_plugins_from_update() {
        if ( $themes_transient = get_site_transient( 'update_themes' ) ) {
            if ( property_exists( $themes_transient, 'response' ) && is_array( $themes_transient->response ) ) {
                foreach ( $themes_transient->response as $key => $value ) {
                    $theme = wp_get_theme( $value['theme'] );
                    $theme_uri = $theme->get( 'ThemeURI' );
                    if ( 0 !== strpos( $theme_uri, 'mythemeshop.com' ) ) {
                        unset( $themes_transient->response[$key] );
                    }
                }
                set_site_transient( 'update_themes', $themes_transient );
            }
        }
        if ( $plugins_transient = get_site_transient( 'update_plugins' ) ) {
            if ( property_exists( $plugins_transient, 'response' ) && is_array( $plugins_transient->response ) ) {
                foreach ( $plugins_transient->response as $key => $value ) {
                    $plugin = get_plugin_data( WP_PLUGIN_DIR.'/'.$key, false, false );
                    $plugin_uri = $plugin['PluginURI'];
                    if ( 0 !== strpos( $plugin_uri, 'mythemeshop.com' ) ) {
                        unset( $plugins_transient->response[$key] );
                    }
                }
                set_site_transient( 'update_plugins', $plugins_transient );
            }
        }
    }

}
// Disable auto update
add_filter( 'auto_update_theme', '__return_false' );

/*-----------------------------------------------------------------------------------*/
/*  Create Blog page on Theme Activation
/*-----------------------------------------------------------------------------------*/
if (isset($_GET['activated']) && is_admin()){
        $new_page_title = 'Blog';
        $new_page_content = '';
        $new_page_template = 'page-blog.php';
        //don't change the code bellow, unless you know what you're doing
        $page_check = get_page_by_title($new_page_title);
        $new_page = array(
                'post_type' => 'page',
                'post_title' => $new_page_title,
                'post_content' => $new_page_content,
                'post_status' => 'publish',
                'post_author' => 1,
        );
        if(!isset($page_check->ID)){
                $new_page_id = wp_insert_post($new_page);
                if(!empty($new_page_template)){
                        update_post_meta($new_page_id, '_wp_page_template', $new_page_template);
                }
        $page_id = $new_page_id;
        } else {
        $page_id = $page_check->ID;
    }
}

/*-----------------------------------------------------------------------------------*/
/*	Post Thumbnail Support
/*-----------------------------------------------------------------------------------*/
if ( function_exists( 'add_theme_support' ) ) { 
	add_theme_support( 'post-thumbnails' );
    function mts_add_image_sizes() {
    	set_post_thumbnail_size( 223, 137, true );
    	add_image_size( 'featured', 688, 350, true ); //featured
    	add_image_size( 'widgetthumb', 74, 74, true ); //widget
        add_image_size( 'widgetfull', 318, 200, true ); //sidebar full width
        add_image_size( 'gallerythumb', 200, 200, true ); //Gallery Archive

        add_image_size( 'wp_review_small', 74, 74, true ); // small thumb
        add_image_size( 'wp_review_large', 318, 200, true ); // large thumb
    }
    add_action( 'init', 'mts_add_image_sizes', 11 );
}

function mts_get_thumbnail_url( $size = 'full' ) {
    global $post;
    if (has_post_thumbnail( $post->ID ) ) {
        $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), $size );
        return $image[0];
    }
    
    // use first attached image
    $images =& get_children( 'post_type=attachment&post_mime_type=image&post_parent=' . $post->ID );
    if (!empty($images)) {
        $image = reset($images);
        $image_data = wp_get_attachment_image_src( $image->ID, $size );
        return $image_data[0];
    }
        
    // use no preview fallback
    if ( file_exists( get_template_directory().'/images/nothumb-'.$size.'.png' ) )
        return get_template_directory_uri().'/images/nothumb-'.$size.'.png';
    else
        return '';
}

/*-----------------------------------------------------------------------------------*/
/*  CREATE AND SHOW COLUMN FOR FEATURED IN PORTFOLIO ITEMS LIST ADMIN PAGE
/*-----------------------------------------------------------------------------------*/

//Get Featured image
function mts_get_featured_image($post_ID) {  
    $post_thumbnail_id = get_post_thumbnail_id($post_ID);  
    if ($post_thumbnail_id) {  
        $post_thumbnail_img = wp_get_attachment_image_src($post_thumbnail_id, 'widgetfull');  
        return $post_thumbnail_img[0];  
    }  
} 
function mts_columns_head($defaults) {  
    $defaults['featured_image'] = 'Featured Image';
    return $defaults;  
}  
function mts_columns_content($column_name, $post_ID) {  
    if ($column_name == 'featured_image') {  
        $post_featured_image = mts_get_featured_image($post_ID);  
        if ($post_featured_image) {  
            echo '<img width="150" height="100" src="' . $post_featured_image . '" />';  
        }  
    }  
} 
add_filter('manage_posts_columns', 'mts_columns_head');  
add_action('manage_posts_custom_column', 'mts_columns_content', 10, 2);

/*-----------------------------------------------------------------------------------*/
/*	Use first attached image as post thumbnail (fallback)
/*-----------------------------------------------------------------------------------*/
add_filter( 'post_thumbnail_html', 'mts_post_image_html', 10, 5 );
function mts_post_image_html( $html, $post_id, $post_image_id, $size, $attr ) {
    if ( has_post_thumbnail() || get_post_type( $post_id ) != 'post'  )
        return $html;
    
    // use first attached image
    $images = get_children( 'post_type=attachment&post_mime_type=image&post_parent=' . $post_id );
    if (!empty($images)) {
        $image = reset($images);
        return wp_get_attachment_image( $image->ID, $size, false, $attr );
    }
        
    // use no preview fallback
    if ( file_exists( get_template_directory().'/images/nothumb-'.$size.'.png' ) )
        return '<img src="'.get_template_directory_uri().'/images/nothumb-'.$size.'.png" class="attachment-'.$size.' wp-post-image" alt="'.get_the_title().'">';
    else
        return '';
    
}

/*-----------------------------------------------------------------------------------*/
/*	Custom Menu Support
/*-----------------------------------------------------------------------------------*/
add_theme_support( 'menus' );
if ( function_exists( 'register_nav_menus' ) ) {
	register_nav_menus(
		array(
		  'primary-menu' => __( 'Top Menu', 'mythemeshop' ),
          'footer-menu' => __( 'Footer Menu', 'mythemeshop' )
		 )
	 );
}

/*-----------------------------------------------------------------------------------*/
/*	Enable Widgetized sidebar and Footer
/*-----------------------------------------------------------------------------------*/
if ( function_exists( 'register_sidebar' ) ) {   
    function mts_register_sidebars() {
        $mts_options = get_option( MTS_THEME_NAME );
        
        // Default sidebar
        register_sidebar( array(
            'name' => 'Sidebar',
            'description'   => __( 'Default sidebar.', 'mythemeshop' ),
            'id' => 'sidebar',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ) );

        // Top level footer widget areas
        if ( !empty( $mts_options['mts_top_footer'] )) {
            register_sidebars( '3', array(
                'name' => __( 'Home Footer %d', 'mythemeshop' ),
                'description'   => __( 'Appears at the top of the footer on Homepage.', 'mythemeshop' ),
                'id' => 'footer-top',
                'before_widget' => '<div id="%1$s" class="widget %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h3 class="widget-title">',
                'after_title' => '</h3>',
            ) );
        }
        // Bottom level footer widget areas
        if ( !empty( $mts_options['mts_bottom_footer'] )) {
            register_sidebars( '3', array(
                'name' => __( 'Footer %d', 'mythemeshop' ),
                'description'   => __( 'Appears at the bottom of the footer.', 'mythemeshop' ),
                'id' => 'footer-bottom',
                'before_widget' => '<div id="%1$s" class="widget %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h3 class="widget-title">',
                'after_title' => '</h3>',
            ) );
        }
        
        // Custom sidebars
        if ( !empty( $mts_options['mts_custom_sidebars'] ) && is_array( $mts_options['mts_custom_sidebars'] )) {
            foreach( $mts_options['mts_custom_sidebars'] as $sidebar ) {
                if ( !empty( $sidebar['mts_custom_sidebar_id'] ) && !empty( $sidebar['mts_custom_sidebar_id'] ) && $sidebar['mts_custom_sidebar_id'] != 'sidebar-' ) {
                    register_sidebar( array( 'name' => ''.$sidebar['mts_custom_sidebar_name'].'', 'id' => ''.sanitize_title( strtolower( $sidebar['mts_custom_sidebar_id'] )).'', 'before_widget' => '<div id="%1$s" class="widget %2$s">', 'after_widget' => '</div>', 'before_title' => '<h3>', 'after_title' => '</h3>' ));
                }
            }
        }
    }
    
    add_action( 'widgets_init', 'mts_register_sidebars' );
}

function mts_custom_sidebar() {
    $mts_options = get_option( MTS_THEME_NAME );
    
	// Default sidebar
	$sidebar = 'Sidebar';

    if ( is_single() && !empty( $mts_options['mts_sidebar_for_post'] )) $sidebar = $mts_options['mts_sidebar_for_post'];
    if ( is_page() && !empty( $mts_options['mts_sidebar_for_page'] )) $sidebar = $mts_options['mts_sidebar_for_page'];
    
    // Archives
	if ( is_archive() && !empty( $mts_options['mts_sidebar_for_archive'] )) $sidebar = $mts_options['mts_sidebar_for_archive'];
	if ( is_category() && !empty( $mts_options['mts_sidebar_for_category'] )) $sidebar = $mts_options['mts_sidebar_for_category'];
    if ( is_tag() && !empty( $mts_options['mts_sidebar_for_tag'] )) $sidebar = $mts_options['mts_sidebar_for_tag'];
    if ( is_date() && !empty( $mts_options['mts_sidebar_for_date'] )) $sidebar = $mts_options['mts_sidebar_for_date'];
	if ( is_author() && !empty( $mts_options['mts_sidebar_for_author'] )) $sidebar = $mts_options['mts_sidebar_for_author'];
    
    // Other
    if ( is_search() && !empty( $mts_options['mts_sidebar_for_search'] )) $sidebar = $mts_options['mts_sidebar_for_search'];
	if ( is_404() && !empty( $mts_options['mts_sidebar_for_notfound'] )) $sidebar = $mts_options['mts_sidebar_for_notfound'];
    
	// Page/post specific custom sidebar
	if ( is_page() || is_single() ) {
		wp_reset_postdata();
		global $post;
        $custom = get_post_meta( $post->ID, '_mts_custom_sidebar', true );
		if ( !empty( $custom )) $sidebar = $custom;
	}

	return $sidebar;
}

/*-----------------------------------------------------------------------------------*/
/*  Load Widgets, Actions and Libraries
/*-----------------------------------------------------------------------------------*/

// Add the 125x125 Ad Block Custom Widget
include_once( "functions/widget-ad125.php" );

// Add the 300x250 Ad Block Custom Widget
include_once( "functions/widget-ad300.php" );

// Add the Latest Tweets Custom Widget
include_once( "functions/widget-tweets.php" );

// Add Recent Posts Widget
include_once( "functions/widget-recentposts.php" );

// Add Related Posts Widget
include_once( "functions/widget-relatedposts.php" );

// Add Author Posts Widget
include_once( "functions/widget-authorposts.php" );

// Add Popular Posts Widget
include_once( "functions/widget-popular.php" );

// Add Facebook Like box Widget
include_once( "functions/widget-fblikebox.php" );

// Add Social Profile Widget
include_once( "functions/widget-social.php" );

// Add Category Posts Widget
include_once( "functions/widget-catposts.php" );

// Add Category Posts Widget
include_once( "functions/widget-postslider.php" );

// Add Events Widget
include_once( "functions/widget-events.php" );

// Add Gallery Widget
include_once( "functions/widget-gallery.php" );

// Add About Us Widget
include_once( "functions/widget-about.php" );

// Add Open Hours Widget
include_once( "functions/widget-open-hours.php" );

// Add Testimonials Widget
include_once( "functions/widget-testimonials.php" );

// Add Welcome message
include_once( "functions/welcome-message.php" );

// Template Functions
include_once( "functions/theme-actions.php" );

// Post/page editor meta boxes
include_once( "functions/metaboxes.php" );

// TGM Plugin Activation
include_once( "functions/plugin-activation.php" );

// AJAX Contact Form - mts_contact_form()
include_once( 'functions/contact-form.php' );

// Custom menu walker
include_once( 'functions/nav-menu.php' );

/*-----------------------------------------------------------------------------------*/
/*	RTL language support - also in mts_load_footer_scripts()
/*-----------------------------------------------------------------------------------*/
if ( ! empty( $mts_options['mts_rtl'] ) ) {
    function mts_rtl() {
        global $wp_locale, $wp_styles;
        $wp_locale->text_direction = 'rtl';
    	if ( ! is_a( $wp_styles, 'WP_Styles' ) ) {
    		$wp_styles = new WP_Styles();
    		$wp_styles->text_direction = 'rtl';
    	}
    }
    add_action( 'init', 'mts_rtl' );
}

/*-----------------------------------------------------------------------------------*/
/*	Filters customize wp_title
/*-----------------------------------------------------------------------------------*/
function mts_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'mythemeshop' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'mts_wp_title', 10, 2 );

/*-----------------------------------------------------------------------------------*/
/*	Javascript
/*-----------------------------------------------------------------------------------*/
function mts_nojs_js_class() {
    echo '<script type="text/javascript">document.documentElement.className = document.documentElement.className.replace( /\bno-js\b/,\'js\' );</script>';
}
add_action( 'wp_head', 'mts_nojs_js_class', 1 );

function mts_add_scripts() {
	$mts_options = get_option( MTS_THEME_NAME );

	wp_enqueue_script( 'jquery' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	wp_register_script( 'customscript', get_template_directory_uri() . '/js/customscript.js', true );
    if ( ! empty( $mts_options['mts_show_primary_nav'] ) && ! empty( $mts_options['mts_show_footer_nav'] ) ) {
        $nav_menu = 'both';
    } else {
        if ( ! empty( $mts_options['mts_show_primary_nav'] ) ) {
            $nav_menu = 'primary';
        } elseif ( ! empty( $mts_options['mts_show_footer_nav'] ) ) {
            $nav_menu = 'footer';
        } else {
            $nav_menu = 'none';
        }
    }
    wp_localize_script(
    	'customscript',
    	'mts_customscript',
    	array(
			'responsive' => ( empty( $mts_options['mts_responsive'] ) ? false : true ),
            'nav_menu' => $nav_menu
    	 )
    );
	wp_enqueue_script( 'customscript' );	
    
	// Slider
    wp_register_script( 'mts_flexslider', get_template_directory_uri() . '/js/jquery.flexslider-min.js' );
	if ( ! empty( $mts_options['mts_featured_slider'] ) && !is_singular() ) {
		wp_enqueue_script ( 'mts_flexslider'
 );
	}
    
    // Parallax pages and posts
    if (is_singular()) {
        if ( basename( mts_get_post_template() ) == 'singlepost-parallax.php' || basename( get_page_template() ) == 'page-parallax.php' ) {
            wp_register_script ( 'jquery-parallax', get_template_directory_uri() . '/js/parallax.js' );
            wp_enqueue_script ( 'jquery-parallax' );
        }
    }

	global $is_IE;
    if ( $is_IE ) {
        wp_register_script ( 'html5shim', "http://html5shim.googlecode.com/svn/trunk/html5.js" );
        wp_enqueue_script ( 'html5shim' );
	}
    
}
add_action( 'wp_enqueue_scripts', 'mts_add_scripts' );
   
function mts_load_footer_scripts() {  
	$mts_options = get_option( MTS_THEME_NAME );
	
	//Lightbox
	if ( ! empty( $mts_options['mts_lightbox'] ) ) {
		wp_register_script( 'prettyPhoto', get_template_directory_uri() . '/js/jquery.prettyPhoto.js', true );
		wp_enqueue_script( 'prettyPhoto' );
	}
    
    // RTL
    if ( ! empty( $mts_options['mts_rtl'] ) ) {
		wp_register_style( 'mts_rtl', get_template_directory_uri() . '/css/rtl.css', 'style', true );
		wp_enqueue_style( 'mts_rtl' );
	}
    
    // Ajax Load More and Search Results
    wp_register_script( 'mts_ajax', get_template_directory_uri() . '/js/ajax.js', true );
	if( ! empty( $mts_options['mts_pagenavigation_type'] ) && $mts_options['mts_pagenavigation_type'] >= 2
        || ! empty( $mts_options['mts_gallery_navigation_type'] ) && $mts_options['mts_gallery_navigation_type'] >= 2 && !is_singular() ) {
		wp_enqueue_script( 'mts_ajax' );
        
        wp_register_script( 'historyjs', get_template_directory_uri() . '/js/history.js', true );
        wp_enqueue_script( 'historyjs' );
        
        // Add parameters for the JS
        if (get_post_type() == 'gallery') {
            $paged = 0;
            if ( get_query_var('page') ) $paged = get_query_var('page');
            if ( get_query_var('paged') ) $paged = get_query_var('paged');
            if (!$paged) $paged = 1;
            $gallery_query = new WP_Query();
            $gallery_query->query('post_type=gallery&order=DESC&ignore_sticky_posts=1&paged='.$paged.'&posts_per_page='.$mts_options['mts_gallery_items']);
            $autoload = ( $mts_options['mts_gallery_navigation_type'] == 3 );
            $max = $gallery_query->max_num_pages;
        } else {
            global $wp_query;
            $max = $wp_query->max_num_pages;
            $paged = 0;
            if ( get_query_var('paged') ) $paged = get_query_var('paged');
            if ( get_query_var('page') ) $paged = get_query_var('page');
            if (!$paged) $paged = 1;
            $autoload = ( $mts_options['mts_pagenavigation_type'] == 3 );
        }
        wp_localize_script(
                'mts_ajax',
                'mts_ajax_loadposts',
                array(
                    'startPage' => $paged,
                    'maxPages' => $max,
                    'nextLink' => next_posts( $max, false ),
                    'autoLoad' => $autoload,
                    'i18n_loadmore' => __( 'Load More Posts', 'mythemeshop' ),
                    'i18n_loading' => __('Loading...', 'mythemeshop'),
                    'i18n_nomore' => __( 'No more posts.', 'mythemeshop' )
                 )
            );
	}
    if ( ! empty( $mts_options['mts_ajax_search'] ) ) {
        wp_enqueue_script( 'mts_ajax' );
        wp_localize_script(
        	'mts_ajax',
        	'mts_ajax_search',
        	array(
				'url' => admin_url( 'admin-ajax.php' ),
        		'ajax_search' => '1'
        	 )
        );
    }
    
}  
add_action( 'wp_footer', 'mts_load_footer_scripts' );  

if( !empty( $mts_options['mts_ajax_search'] )) {
    add_action( 'wp_ajax_mts_search', 'ajax_mts_search' );
    add_action( 'wp_ajax_nopriv_mts_search', 'ajax_mts_search' );
}

/*-----------------------------------------------------------------------------------*/
/* Enqueue CSS
/*-----------------------------------------------------------------------------------*/
function mts_enqueue_css() {
	$mts_options = get_option( MTS_THEME_NAME );

    wp_enqueue_style( 'stylesheet', get_stylesheet_directory_uri() . '/style.css', 'style' );
    
	// Slider
    wp_register_style( 'mts_flexslider'
, get_template_directory_uri() . '/css/flexslider.css', 'style' );
	if ( ! empty( $mts_options['mts_featured_slider'] ) && !is_singular() ) {
		wp_enqueue_style( 'mts_flexslider'
 );
	}
    // also enqueued in slider widget
	
	// Lightbox
	if ( ! empty( $mts_options['mts_lightbox'] ) ) {
		wp_register_style( 'prettyPhoto', get_template_directory_uri() . '/css/prettyPhoto.css', 'style' );
		wp_enqueue_style( 'prettyPhoto' );
	}
	
	//Font Awesome
	wp_register_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css', 'style' );
	wp_enqueue_style( 'fontawesome' );
	
	//Responsive
	if ( ! empty( $mts_options['mts_responsive'] ) ) {
        wp_enqueue_style( 'responsive', get_template_directory_uri() . '/css/responsive.css', 'style' );
	}

    $mts_sclayout = '';
	$mts_shareit_left = '';
	$mts_shareit_right = '';
	$mts_author = '';
	$mts_header_section = '';
    if ( is_page() || is_single() ) {
        $mts_sidebar_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
    } else {
        $mts_sidebar_location = '';
    }
	if ( $mts_sidebar_location != 'right' && ( $mts_options['mts_layout'] == 'sclayout' || $mts_sidebar_location == 'left' )) {
		$mts_sclayout = '.article { float: right;}
		.sidebar.c-4-12 { float: left; padding-right: 0; }';
		if( isset( $mts_options['mts_social_button_position'] ) && $mts_options['mts_social_button_position'] == 'floating' ) {
			$mts_shareit_right = '.shareit { margin: 0 760px 0; border-left: 0; }';
		}
	}
	if ( empty( $mts_options['mts_header_section2'] ) ) {
		$mts_header_section = '.logo-wrap, .widget-header { display: none; }
		#navigation { border-top: 0; }
        .primary-navigation { float: left; }';
	}
	if ( isset( $mts_options['mts_social_button_position'] ) && $mts_options['mts_social_button_position'] == 'floating' ) {
		$mts_shareit_left = '.shareit { top: 392px; left: auto; z-index: 0; margin: 0 0 0 -102px; width: 90px; position: fixed; overflow: hidden; padding: 5px; border:none; border-right: 0;}
		.share-item {margin: 2px;}';
	}
	if ( ! empty( $mts_options['mts_author_comment'] ) ) {
		$mts_author = '.bypostauthor { width: 100%!important;}
		.bypostauthor .fn > span:after { content: "Author"; margin-left: 10px; color: #FFF; -webkit-border-radius: 2px; border-radius: 2px; padding: 1px 8px; }';
	}
	$custom_css = "
        .header-wrap { background-color: {$mts_options['mts_header_bg_color']}; }
        .pace .pace-progress, #mobile-menu-wrapper ul li a:hover { background: {$mts_options['mts_color_scheme']}; }
		.copyrights a, .single-post-content a, #logo a, .pnavigation2 a, .sidebar.c-4-12 a:hover, .copyrights a:hover, footer .widget li a:hover, .sidebar.c-4-12 a:hover, .related-posts a:hover, .title a:hover, .post-info a:hover, .comm, #tabber .inside li a:hover, .fn a, a, a:hover, #sidebars .widget a:hover, .footer-widgets .widget a:hover, #copyright-note a:hover, #sidebars .widget .title-right a:hover, .footer-widgets .widget .title-right a:hover, #sidebars .widget .wpt_widget_content .entry-title a:hover, .footer-widgets .widget .wpt_widget_content .entry-title a:hover, #sidebars .widget .wpt_comment_meta a:hover, .footer-widgets .widget .wpt_comment_meta a:hover, #sidebars .widget .textwidget a, .footer-widgets .widget .textwidget a, #sidebars .widget .advanced-recent-posts li a:hover, #sidebars .widget .popular-posts li a:hover, #sidebars .widget .category-posts li a:hover, #sidebars .widget .related-posts-widget li a:hover, #sidebars .widget .author-posts-widget li a:hover, .footer-widgets .widget .advanced-recent-posts li a:hover, .footer-widgets .widget .popular-posts li a:hover, .footer-widgets .widget .category-posts li a:hover, .footer-widgets .widget .related-posts-widget li a:hover, .footer-widgets .widget .author-posts-widget li a:hover, .latestPost .title a:hover { color:{$mts_options['mts_color_scheme']}; }	
			#navigation ul ul li:hover > a, nav a#pull, #move-to-top:hover, #navigation ul .current-menu-item > a, #tabber ul.tabs li a.selected, .tagcloud a:hover, .site-description, .widget .event-link, .widget .gallery-link, .flex-control-paging li a.flex-active, .flex-control-paging li a:hover, .page-header #filters li a:hover, .currenttext, .pagination a:hover, .single .pagination a:hover .currenttext, .page-header #filters li a.selected, .page-header #filters li.current-cat a, .post-info .thecategory a:hover, .readMore a, .widget .wpt_widget_content #tags-tab-content ul li a:hover, .widget-slider .flex-direction-nav li, .reply a, #commentform input#submit:hover, #mtscontact_submit:hover, .pagination .nav-previous a:hover, .pagination .nav-next a:hover:hover, #load-posts a:hover { background-color:{$mts_options['mts_color_scheme']}; color: #fff!important; }
		.flex-control-thumbs .flex-active { border-top:3px solid {$mts_options['mts_color_scheme']};}
        #navigation ul li:hover > a, #navigation ul ul li a, #move-to-top, .widget .event-link:hover, .widget .gallery-link:hover, .pagination a, .readMore a:hover, .latestPost-review-wrapper, .widget-slider .flex-direction-nav li:hover, .widget .widget-slider .flex-caption, .reply a:hover, #commentform input#submit, #mtscontact_submit, #load-posts a { background-color:{$mts_options['mts_secondary_color_scheme']}; color: #fff!important; }
        .review-type-circle.review-total-only, .review-type-circle.wp-review-show-total, .review-total-only, .bypostauthor .fn > span:after { background-color:{$mts_options['mts_secondary_color_scheme']}!important; color: #fff; }
		{$mts_sclayout}
		{$mts_shareit_left}
		{$mts_shareit_right}
		{$mts_author}
		{$mts_header_section}
		{$mts_options['mts_custom_css']}
			";
	wp_add_inline_style( 'stylesheet', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'mts_enqueue_css', 99 );

/*-----------------------------------------------------------------------------------*/
/*	Wrap videos in .responsive-video div
/*-----------------------------------------------------------------------------------*/
function mts_responsive_video( $data ) {
    return '<div class="flex-video">' . $data . '</div>';
}
add_filter( 'embed_oembed_html', 'mts_responsive_video' );

/*-----------------------------------------------------------------------------------*/
/*	Filters that allow shortcodes in Text Widgets
/*-----------------------------------------------------------------------------------*/
add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );
add_filter( 'the_content_rss', 'do_shortcode' );

/*-----------------------------------------------------------------------------------*/
/*	Custom Comments template
/*-----------------------------------------------------------------------------------*/
function mts_comments( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment; 
    $mts_options = get_option( MTS_THEME_NAME ); ?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
		<div id="comment-<?php comment_ID(); ?>" itemprop="comment" itemscope itemtype="http://schema.org/UserComments">
			<div class="comment-author vcard">
				<?php echo get_avatar( $comment->comment_author_email, 94 ); ?>
				<?php printf( '<span class="fn" itemprop="creator" itemscope itemtype="http://schema.org/Person"><span itemprop="name">%s</span></span>', get_comment_author_link() ) ?> 
				<?php if ( ! empty( $mts_options['mts_comment_date'] ) ) { ?>
					<span class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></span>
				<?php } ?>
				<span class="comment-meta">
					<?php edit_comment_link( __( '( Edit )', 'mythemeshop' ), '  ', '' ) ?>
				</span>
                <span class="reply">
                    <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] )) ) ?>
                </span>
			</div>
			<?php if ( $comment->comment_approved == '0' ) : ?>
				<em><?php _e( 'Your comment is awaiting moderation.', 'mythemeshop' ) ?></em>
				<br />
			<?php endif; ?>
			<div class="commentmetadata">
                <div class="commenttext" itemprop="commentText">
				    <?php comment_text() ?>
                </div>
			</div>
		</div>
	</li>
<?php }

/*-----------------------------------------------------------------------------------*/
/*	Excerpt
/*-----------------------------------------------------------------------------------*/

// Increase max length
function mts_excerpt_length( $length ) {
	return 100;
}
add_filter( 'excerpt_length', 'mts_excerpt_length', 20 );

// Remove [...] and shortcodes
function mts_custom_excerpt( $output ) {
  return preg_replace( '/\[[^\]]*]/', '', $output );
}
add_filter( 'get_the_excerpt', 'mts_custom_excerpt' );

// Truncate string to x letters/words
function mts_truncate( $str, $length = 40, $units = 'letters', $ellipsis = '&nbsp;&hellip;' ) {
    if ( $units == 'letters' ) {
        if ( mb_strlen( $str ) > $length ) {
            return mb_substr( $str, 0, $length ) . $ellipsis;
        } else {
            return $str;
        }
    } else {
        $words = explode( ' ', $str );
        if ( count( $words ) > $length ) {
            return implode( " ", array_slice( $words, 0, $length ) ) . $ellipsis;
        } else {
            return $str;
        }
    }
}

if ( ! function_exists( 'mts_excerpt' ) ) {
    function mts_excerpt( $limit = 40 ) {
      return mts_truncate( get_the_excerpt(), $limit, 'words' );
    }
}

/*-----------------------------------------------------------------------------------*/
/*	Remove more link from the_content and use custom read more
/*-----------------------------------------------------------------------------------*/
add_filter( 'the_content_more_link', 'mts_remove_more_link', 10, 2 );
function mts_remove_more_link( $more_link, $more_link_text ) {
	return '';
}
// shorthand function to check for more tag in post
function mts_post_has_moretag() {
    global $post;
    return strpos( $post->post_content, '<!--more-->' );
}

if ( ! function_exists( 'mts_readmore' ) ) {
    function mts_readmore() {
        ?>
        <div class="readMore">
            <a href="<?php the_permalink() ?>" title="<?php the_title(); ?>" rel="nofollow">
                <?php _e( 'Read More', 'mythemeshop' ); ?>
            </a>
        </div>
        <?php 
    }
}

/*-----------------------------------------------------------------------------------*/
/* nofollow to next/previous links
/*-----------------------------------------------------------------------------------*/
function mts_pagination_add_nofollow( $content ) {
    return 'rel="nofollow"';
}
add_filter( 'next_posts_link_attributes', 'mts_pagination_add_nofollow' );
add_filter( 'previous_posts_link_attributes', 'mts_pagination_add_nofollow' );

/*-----------------------------------------------------------------------------------*/
/* Nofollow to category links
/*-----------------------------------------------------------------------------------*/
add_filter( 'the_category', 'mts_add_nofollow_cat' ); 
function mts_add_nofollow_cat( $text ) {
    $text = str_replace( 'rel="category tag"', 'rel="nofollow"', $text ); return $text;
}

/*-----------------------------------------------------------------------------------*/	
/* nofollow post author link
/*-----------------------------------------------------------------------------------*/
add_filter( 'the_author_posts_link', 'mts_nofollow_the_author_posts_link' );
function mts_nofollow_the_author_posts_link ( $link ) {
    return str_replace( '<a href=', '<a rel="nofollow" href=', $link ); 
}

/*-----------------------------------------------------------------------------------*/	
/* nofollow to reply links
/*-----------------------------------------------------------------------------------*/
function mts_add_nofollow_to_reply_link( $link ) {
    return str_replace( '" )\'>', '" )\' rel=\'nofollow\'>', $link );
}
add_filter( 'comment_reply_link', 'mts_add_nofollow_to_reply_link' );

/*-----------------------------------------------------------------------------------*/
/* removes the WordPress version from your header for security
/*-----------------------------------------------------------------------------------*/
function mts_remove_wpversion() {
	return '<!--Theme by MyThemeShop.com-->';
}
add_filter( 'the_generator', 'mts_remove_wpversion' );
	
/*-----------------------------------------------------------------------------------*/
/* Removes Trackbacks from the comment count
/*-----------------------------------------------------------------------------------*/
add_filter( 'get_comments_number', 'mts_comment_count', 0 );
function mts_comment_count( $count ) {
	if ( ! is_admin() ) {
		global $id;
        $comments = get_comments( 'status=approve&post_id=' . $id );
        $comments_by_type = separate_comments( $comments );
		return count( $comments_by_type['comment'] );
	} else {
		return $count;
	}
}

/*-----------------------------------------------------------------------------------*/
/* adds a class to the post if there is a thumbnail
/*-----------------------------------------------------------------------------------*/
function has_thumb_class( $classes ) {
    global $post;
    if( has_post_thumbnail( $post->ID ) ) { $classes[] = 'has_thumb'; }
        return $classes;
}
add_filter( 'post_class', 'has_thumb_class' );

/*-----------------------------------------------------------------------------------*/	
/* AJAX Search results
/*-----------------------------------------------------------------------------------*/
function ajax_mts_search() {
    $query = $_REQUEST['q']; // It goes through esc_sql() in WP_Query
    $search_query = new WP_Query( array( 's' => $query, 'posts_per_page' => 3, 'post_status' => 'publish' )); 
    $search_count = new WP_Query( array( 's' => $query, 'posts_per_page' => -1, 'post_status' => 'publish' ));
    $search_count = $search_count->post_count;
    if ( !empty( $query ) && $search_query->have_posts() ) : 
        //echo '<h5>Results for: '. $query.'</h5>';
        echo '<ul class="ajax-search-results">';
        while ( $search_query->have_posts() ) : $search_query->the_post();
            ?><li>
    			<div class="post-img">
                    <a rel="nofollow" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
                        <?php the_post_thumbnail( 'widgetthumb', array( 'title' => '' ) ); ?>
                    </a>
                </div>
                <div class="post-data">
                    <div class="post-data-container">
                        <div class="post-title">
                            <a href="<?php the_permalink()?>" title="<?php the_title(); ?>"><?php the_title(); ?></a>
                        </div>
                        <div class="post-info">
                            <span class="thetime updated"><?php the_time( get_option( 'date_format' ) ); ?></span>
                            <br/>
                            <span class="thecomment"><?php echo comments_number(__('0 Comments','mythemeshop'),__('1 Comment','mythemeshop'),'% '.__('Comments','mythemeshop'));?></span>
                        </div> <!--.post-info-->
                    </div>
                </div>
    		</li>	
    		<?php
        endwhile;
        echo '</ul>';
        echo '<div class="ajax-search-meta"><span class="results-count">'.$search_count.' '.__( 'Results', 'mythemeshop' ).'</span><a href="'.get_search_link( $query ).'" class="results-link">Show all results</a></div>';
    else:
        echo '<div class="no-results">'.__( 'No results found.', 'mythemeshop' ).'</div>';
    endif;
        
    exit; // required for AJAX in WP
}

/*-----------------------------------------------------------------------------------*/
/* Redirect feed to feedburner
/*-----------------------------------------------------------------------------------*/

if ( $mts_options['mts_feedburner'] != '' ) {
function mts_rss_feed_redirect() {
    $mts_options = get_option( MTS_THEME_NAME );
    global $feed;
    $new_feed = $mts_options['mts_feedburner'];
    if ( !is_feed() ) {
            return;
    }
    if ( preg_match( '/feedburner/i', $_SERVER['HTTP_USER_AGENT'] )){
            return;
    }
    if ( $feed != 'comments-rss2' ) {
            if ( function_exists( 'status_header' )) status_header( 302 );
            header( "Location:" . $new_feed );
            header( "HTTP/1.1 302 Temporary Redirect" );
            exit();
    }
}
add_action( 'template_redirect', 'mts_rss_feed_redirect' );
}

/*-----------------------------------------------------------------------------------*/
/* Single Post Pagination - Numbers + Previous/Next
/*-----------------------------------------------------------------------------------*/
function mts_wp_link_pages_args( $args ) {
    global $page, $numpages, $more, $pagenow;
    if ( !$args['next_or_number'] == 'next_and_number' )
        return $args; 
    $args['next_or_number'] = 'number'; 
    if ( !$more )
        return $args; 
    if( $page-1 ) 
        $args['before'] .= _wp_link_page( $page-1 )
        . $args['link_before']. $args['previouspagelink'] . $args['link_after'] . '</a>'
    ;
    if ( $page<$numpages ) 
    
        $args['after'] = _wp_link_page( $page+1 )
        . $args['link_before'] . $args['nextpagelink'] . $args['link_after'] . '</a>'
        . $args['after']
    ;
    return $args;
}
add_filter( 'wp_link_pages_args', 'mts_wp_link_pages_args' );

/*-----------------------------------------------------------------------------------*/
/* add <!-- next-page --> button to tinymce
/*-----------------------------------------------------------------------------------*/
add_filter( 'mce_buttons', 'wysiwyg_editor' );
function wysiwyg_editor( $mce_buttons ) {
   $pos = array_search( 'wp_more', $mce_buttons, true );
   if ( $pos !== false ) {
       $tmp_buttons = array_slice( $mce_buttons, 0, $pos+1 );
       $tmp_buttons[] = 'wp_page';
       $mce_buttons = array_merge( $tmp_buttons, array_slice( $mce_buttons, $pos+1 ));
   }
   return $mce_buttons;
}

/*-----------------------------------------------------------------------------------*/
/*	Alternative post templates
/*-----------------------------------------------------------------------------------*/
function mts_get_post_template( $default = 'default' ) {
    global $post;
    $single_template = $default;
    $posttemplate = get_post_meta( $post->ID, '_mts_posttemplate', true );
    
    if ( empty( $posttemplate ) || ! is_string( $posttemplate ) )
        return $single_template;
    
    if ( file_exists( dirname( __FILE__ ) . '/singlepost-'.$posttemplate.'.php' ) ) {
        $single_template = dirname( __FILE__ ) . '/singlepost-'.$posttemplate.'.php';
    }
    
    return $single_template;
}
function mts_set_post_template( $single_template ) {
     return mts_get_post_template( $single_template );
}
add_filter( 'single_template', 'mts_set_post_template' );

/*-----------------------------------------------------------------------------------*/
/*	Custom Gravatar Support
/*-----------------------------------------------------------------------------------*/
function mts_custom_gravatar( $avatar_defaults ) {
    $mts_avatar = get_template_directory_uri() . '/images/gravatar.png';
    $avatar_defaults[$mts_avatar] = 'Custom Gravatar ( /images/gravatar.png )';
    return $avatar_defaults;
}
add_filter( 'avatar_defaults', 'mts_custom_gravatar' );

/*-----------------------------------------------------------------------------------*/
/*  WP Review Support
/*-----------------------------------------------------------------------------------*/

// Set default colors for new reviews
function new_default_review_colors( $colors ) {
    $colors = array(
        'color' => '#fff',
        'fontcolor' => '#fff',
        'bgcolor1' => '#2bd4f3',
        'bgcolor2' => '#2bd4f3',
        'bordercolor' => '#2bd4f3'
    );
  return $colors;
}
add_filter( 'wp_review_default_colors', 'new_default_review_colors' );
 
// Set default location for new reviews
function new_default_review_location( $position ) {
  $position = 'top';
  return $position;
}
add_filter( 'wp_review_default_location', 'new_default_review_location' );


/*-----------------------------------------------------------------------------------*/
/*  Thumbnail Upscale
/*  Enables upscaling of thumbnails for small media attachments, 
/*  to make sure it fits into it's supposed location.
/*  Cannot be used in conjunction with Retina Support.
/*-----------------------------------------------------------------------------------*/
if ( empty( $mts_options['mts_retina'] ) ) {
    function mts_image_crop_dimensions( $default, $orig_w, $orig_h, $new_w, $new_h, $crop ) {
        if( !$crop )
        	return null; // let the wordpress default function handle this
    
        $aspect_ratio = $orig_w / $orig_h;
        $size_ratio = max( $new_w / $orig_w, $new_h / $orig_h );
    
        $crop_w = round( $new_w / $size_ratio );
        $crop_h = round( $new_h / $size_ratio );
    
        $s_x = floor( ( $orig_w - $crop_w ) / 2 );
        $s_y = floor( ( $orig_h - $crop_h ) / 2 );
    
        return array( 0, 0, ( int ) $s_x, ( int ) $s_y, ( int ) $new_w, ( int ) $new_h, ( int ) $crop_w, ( int ) $crop_h );
    }
    add_filter( 'image_resize_dimensions', 'mts_image_crop_dimensions', 10, 6 );
}

/*-----------------------------------------------------------------------------------*/
/*  CUSTOM POST TYPE FOR EVENT
/*-----------------------------------------------------------------------------------*/ 
add_action( 'init', 'create_event_postype' );
 
function create_event_postype() {
 
$labels = array(
    'name' => __('Events', 'mythemeshop'),
    'singular_name' => __('Event', 'mythemeshop'),
    'add_new' => __('Add New', 'events'),
    'add_new_item' => __('Add New Event','mythemeshop'),
    'edit_item' => __('Edit Event','mythemeshop'),
    'new_item' => __('New Event','mythemeshop'),
    'view_item' => __('View Event','mythemeshop'),
    'search_items' => __('Search Events','mythemeshop'),
    'not_found' =>  __('No events found','mythemeshop'),
    'not_found_in_trash' => __('No events found in Trash','mythemeshop'),
    'parent_item_colon' => '',
);
 
$args = array(
    'label' => __('Events','mythemeshop'),
    'labels' => $labels,
    'public' => true,
    'can_export' => true,
    'show_ui' => true,
    '_builtin' => false,
    'capability_type' => 'post',
    'menu_icon' => 'dashicons-calendar',
    'menu_position' => 5,
    'has_archive' => true,
    'hierarchical' => false,
    'rewrite' => array( "slug" => "events" ),
    'supports'=> array('title', 'editor') ,
    'show_in_nav_menus' => true,
);
 
register_post_type( 'events', $args);
 
}

/*-----------------------------------------------------------------------------------*/
/*  CUSTOM POST TYPE FOR EVENT METABOX
/*-----------------------------------------------------------------------------------*/ 
add_action( 'admin_init', 'mts_events_create' );
 
function mts_events_create() {
    add_meta_box('mts_events_meta', 'Events', 'mts_events_meta', 'events');
}
 
function mts_events_meta () {
 
// - grab data - 
global $post;
$custom = get_post_custom($post->ID);
if(!empty($custom["mts_events_startdate"])){
    $meta_sd = $custom["mts_events_startdate"][0];
}
 
// - grab wp time format - 
$date_format = get_option('date_format'); // Not required in my code
$time_format = get_option('time_format');
 
// - populate today if empty, 00:00 for time - 
if (empty($meta_sd)) { $meta_sd = time(); $meta_ed = $meta_sd; }//$meta_st = 0; $meta_et = 0;}
 
// - convert to pretty formats -
$clean_sd = date("Y-m-d", $meta_sd);
 
// - security - 
echo '<input type="hidden" name="tf-events-nonce" id="tf-events-nonce" value="' .
wp_create_nonce( 'tf-events-nonce' ) . '" />';
 
// - output -
$clean_st = get_post_meta($post->ID, 'mts_events_starttime', true);
$desc = get_post_meta($post->ID, 'mts_events_desc', true);
?>
<div class="">
    <ul>
        <li><label><?php _e('Date','mythemeshop'); ?></label><input name="mts_events_startdate" class="widefat" type="date" value="<?php echo $clean_sd; ?>" /></li>
        <li><label><?php _e('Time','mythemeshop'); ?></label><input name="mts_events_starttime"  class="widefat" value="<?php echo $clean_st; ?>" /></li>
        <li><label><?php _e('Short Description','mythemeshop'); ?></label><textarea name="mts_events_desc" class="widefat" cols="30" rows="10"><?php echo $desc; ?></textarea></li>
    </ul>
</div>
<?php
}

// Save Data 
add_action ('save_post', 'save_mts_events');
 
function save_mts_events(){
 
global $post; 
// - still require nonce
if(!empty($_POST['tf-events-nonce'])){
    if ( !wp_verify_nonce( $_POST['tf-events-nonce'], 'tf-events-nonce' )) {
    return $post->ID;
} 
}
if(!empty($post->ID)){
    if ( !current_user_can( 'edit_post', $post->ID ))
    return $post->ID;
}
 
// - convert back to unix & update post 
if(!isset($_POST["mts_events_startdate"])):
    return $post;
endif;
$updatestartd = strtotime ( $_POST["mts_events_startdate"] );

update_post_meta($post->ID, "mts_events_startdate", $updatestartd ); 

if(!isset($_POST["mts_events_starttime"])):
    return $post;
endif;
$updatestartm = strip_tags( $_POST["mts_events_starttime"] );

update_post_meta($post->ID, "mts_events_starttime", $updatestartm );

if(!isset($_POST["mts_events_desc"])):
    return $post;
endif;
$desc = strip_tags( $_POST["mts_events_desc"] );

update_post_meta($post->ID, "mts_events_desc", $desc );

}

/*-----------------------------------------------------------------------------------*/
/*  Create gallery post type
/*-----------------------------------------------------------------------------------*/

function mts_gallery_register() {
    $labels = array(
        'name' => __('Gallery', 'mythemeshop'),
        'singular_name' => __('Gallery Item', 'mythemeshop'),
        'add_new' => __('Add New', 'events'),
        'add_new_item' => __('Add New Gallery Item','mythemeshop'),
        'edit_item' => __('Edit Gallery Item','mythemeshop'),
        'new_item' => __('New Gallery Item','mythemeshop'),
        'view_item' => __('View Gallery Item','mythemeshop'),
        'search_items' => __('Search Gallery','mythemeshop'),
        'not_found' =>  __('No Gallery Item found','mythemeshop'),
        'not_found_in_trash' => __('No Gallery Item found in Trash','mythemeshop'),
        'parent_item_colon' => '',
    );
     
    $args = array(
        'label' => __('Gallery','mythemeshop'),
        'labels' => $labels,
        'public' => true,
        'can_export' => true,
        'show_ui' => true,
        '_builtin' => false,
        'capability_type' => 'post',
        'menu_icon' => 'dashicons-id',
        'menu_position' => 5,
        'has_archive' => true,
        'hierarchical' => false,
        'rewrite' => array( "slug" => "gallery" ),
        'supports'=> array('title', 'editor', 'thumbnail') ,
        'show_in_nav_menus' => true,
    );
    
register_post_type( 'gallery' , $args );
register_taxonomy("gallery_category", array("gallery"), array("hierarchical" => true, "label" => __('Gallery Categories','mythemeshop'), "singular_label" => __('Gallery Category','mythemeshop'), "rewrite" => true));    
}  
add_action('init', 'mts_gallery_register');   

// Save Data 
add_action ('save_post', 'save_mts_gallery');
 
function save_mts_gallery(){
 
    global $post;
    // - still require nonce
    if(!empty($_POST['tf-gallery-nonce'])){
        if ( !wp_verify_nonce( $_POST['tf-gallery-nonce'], 'tf-gallery-nonce' )) {
            return $post->ID;
        } 
    }
    if(!empty($post->ID)){
        if ( !current_user_can( 'edit_post', $post->ID ))
            return $post->ID;
    }

    if(!isset($_POST["mts_gallery_type"])) {
        return $post;
    }

    $updategallerytype = strip_tags($_POST["mts_gallery_type"]);

    update_post_meta($post->ID, "mts_gallery_type", $updategallerytype);

    $updategalleryvideourl = strip_tags($_POST["mts_gallery_video_url"]);

    update_post_meta($post->ID, "mts_gallery_video_url", $updategalleryvideourl);
}

// Map categories and images in group field after demo content import
add_filter( 'mts_correct_single_import_option', 'mts_correct_homepage_sections_import', 10, 3 );
function mts_correct_homepage_sections_import( $item, $key, $data ) {

    if ( 'mts_custom_slider' !== $key ) return $item;

    $new_item = $item;

    foreach( $item as $i => $image ) {

        $img = $image['mts_custom_slider_image'];
        if ( is_numeric( $img ) ) {

            if ( array_key_exists( $img, $data['posts'] ) ) {

                $new_item[ $i ]['mts_custom_slider_image'] = $data['posts'][ $img ];
            }

        } else {

            if ( array_key_exists( $img, $data['image_urls'] ) ) {

                $new_item[ $i ]['mts_custom_slider_image'] = $data['image_urls'][ $img ];
            }
        }
    }

    return $new_item;
}
